@@ -26,21 +26,9 @@
 
 from cookiecutterassert import folder_scanner
 from cookiecutterassert import test_folder_executor
-from cookiecutterassert import messager
-import os
 
 def runAllTestsInAllFolders(projectRootFolder):
-    rootTestFolder = projectRootFolder+'/test'
-    if (not os.path.isdir(rootTestFolder)):
-        messager.printError(f'No test folder found, expecting to find one at {rootTestFolder}')
-        return False
-
-    testFolders = folder_scanner.findAllTestFolders(rootTestFolder)
-    
-    if (len(testFolders) == 0):
-        messager.printError(f'No test cases found. Expecting to find one or more subdirectories in {rootTestFolder} with valid config.yaml and assertions.yaml files')
-        return False
-
+    testFolders = folder_scanner.findAllTestFolders(projectRootFolder+'/test')
     allTestsPass = True
     for folder in testFolders :
         folderSuccess = test_folder_executor.executeAllTestsInFolder(projectRootFolder, folder)
